import React from "react";
import './App.css';
import {
  Redirect,
  Route,
  BrowserRouter as Router,
  Switch,
} from 'react-router-dom';
import { ThemeProvider } from "@material-ui/core/styles"
import { CssBaseline } from "@material-ui/core";
import { theme } from "./Theme";
import { IOCListView } from './views/IOC/IOCListView';
import { HomeView } from './views/home/HomeView';
import { GlobalAppBar } from './components/navigation/GlobalAppBar/GlobalAppBar';
import { IOCDetailsView } from './views/IOC/IOCDetailsView';
import { DeploymentsView } from './views/deployments/DeploymentsView'
import { DeploymentDetailsView } from './views/deployments/DeploymentDetailsView'
import { APIProvider, UserProvider } from './api/SwaggerApi';
import ProtectedRoute from "./components/auth/ProtectedRoute";
import { LoginView } from "./views/User/LoginView";
import { HostListView } from "./views/host/HostListView";
import { HostDetailsView } from "./views/host/HostDetailsView";
import { StatisticsView } from "./views/statistics/StatisticsView";
import { HelpView } from "./views/help/HelpView";
import { SnackbarProvider } from 'notistack';
import TokenRenew from './components/auth/TokenRenew';
import {NotificationProvider} from './components/common/notification/Notifications';

function App() {

  return (
    <SnackbarProvider preventDuplicate maxSnack="5">
      <ThemeProvider theme={theme}>
        <CssBaseline />
        <Router>
          <APIProvider >
            <UserProvider>
              <TokenRenew />
              <Switch>
                <Route exact path="/login">
                  <LoginView />
                </Route>
                <Route path="/"
                  render={({ match }) => {
                    console.log(match)
                    return (
                      <ProtectedRoute>
                        <NotificationProvider>
                          <GlobalAppBar>
                            <Switch>
                              <Route exact path="/">
                                <Redirect to="/home" />
                              </Route>
                              <Route path="/home" component={HomeView} />
                              <Route path="/iocs/:id" component={IOCDetailsView} />
                              <Route path="/iocs" component={IOCListView} />
                              <Route path="/deployments/:id" component={DeploymentDetailsView} />
                              <Route path="/deployments" component={DeploymentsView} />
                              <Route path="/hosts/:id" component={HostDetailsView} />
                              <Route path="/hosts" component={HostListView} />
                              <Route path="/statistics" component={StatisticsView} />
                              <Route path="/help" component={HelpView} />
                              <Route>
                                <NotFound404 />
                              </Route>
                            </Switch>
                          </GlobalAppBar>
                        </NotificationProvider>  
                      </ProtectedRoute>
                    )
                  }
                  }
                />
                <Route>
                  <NotFound404 />
                </Route>
              </Switch>
            </UserProvider>
          </APIProvider>
        </Router>
      </ThemeProvider>
    </SnackbarProvider>
  );
}

function NotFound404() {
  return (
    <div>
      <h1>404 - Not Found!</h1>
    </div>
  );
}

export default App;
