import React, { useEffect, useState } from "react";
import { Button, TextField, Dialog, DialogActions, DialogContent, DialogTitle, makeStyles } from "@material-ui/core";
import { Autocomplete } from "@material-ui/lab";
import { useNamingNames } from "../../api/SwaggerApi";
import { useTypingTimer } from "../common/SearchBoxFilter/TypingTimer";

const useStyles = makeStyles((theme) => ({
  textField: {
    marginBottom: theme.spacing(1),
  },
}));

export function IOCCreateDialog({ open, setOpen, submitCallback }) {
  const classes = useStyles();
  const [names, getNames] = useNamingNames();
  const [name, setName] = useState();
  const [nameQuery, onNameKeyUp] = useTypingTimer({interval: 500});

  const handleClose = () => {
    setOpen(false);
  };

  console.log("Name: " + JSON.stringify(name));

  useEffect(() => getNames(nameQuery), [nameQuery, getNames]);

  const onSubmit = (event) => {
    event.preventDefault();
    const { git: gitText } = event.currentTarget.elements;
    const git = gitText.value;

    submitCallback({
        sourceUrl: git, 
        externalNameId: name ? parseInt(name.id) : undefined });
  };

  return (
    <Dialog open={open} onClose={handleClose}>
      <form onSubmit={onSubmit}>
        <DialogTitle id="form-dialog-title">Create new IOC</DialogTitle>
        <DialogContent>
          <Autocomplete
            className={classes.textField}
            autoHighlight
            id="nameAutocomplete"
            options={names}
            getOptionLabel={(option) => {console.log(option?.name); return option?.name}}
            renderInput={(params) => <TextField {...params} label="IOC name" variant="outlined" required/>}
            onChange={(event, value, reason) => setName(value)}
            onInputChange={(event, value, reason) => {event && onNameKeyUp(event.nativeEvent)}}
          />

          <TextField autoComplete="off" className={classes.textField} id="description" label="Description"
            variant="outlined" fullWidth disabled value={name? name.description : ""} />
          <TextField autoComplete="off" className={classes.textField} id="git" label="Git repository" variant="outlined" fullWidth required />
        </DialogContent>
        <DialogActions>
          <Button onClick={handleClose} color="primary">Cancel</Button>
          <Button color="primary" variant="contained" type="submit">Create</Button>
        </DialogActions>
      </form>
    </Dialog>
  );
}