import React, { useEffect, useState } from "react";
import { Button, TextField, Dialog, DialogActions, DialogContent, DialogTitle, makeStyles } from "@material-ui/core";
import { Autocomplete } from "@material-ui/lab";
import { useCSEntrySearch } from "../../api/SwaggerApi";
import { useTypingTimer } from "../common/SearchBoxFilter/TypingTimer";

const useStyles = makeStyles((theme) => ({
  textField: {
    marginBottom: theme.spacing(1),
  },
}));

export function IOCDeployDialog({ open, setOpen, submitCallback, init = {}}) {
  const classes = useStyles();
  const [hosts, getHosts] = useCSEntrySearch();
  const [host, setHost] = useState(init.host);
  const [query, onHostKeyUp] = useTypingTimer({interval: 500});

  const handleClose = () => {
    setOpen(false);
  };

  console.log({...init});
  console.log(hosts);
  console.log(host);

  useEffect(() => getHosts(`fqdn:"${query}"`), [query, getHosts]);

  const onSubmit = (event) => {
    event.preventDefault();
    const { comment: commentText, git: gitText, version: versionText } = event.currentTarget.elements;
    const comment = commentText.value;
    const git = gitText.value;
    const version = versionText.value;
    console.log(host);

    submitCallback({  
      comment: comment,
      sourceUrl: git, 
      sourceVersion: version, 
      hostCSEntryId: host ? parseInt(host.csEntryHost.id) : undefined});
  };

  return (
    <Dialog open={open} onClose={handleClose}>
      <form onSubmit={onSubmit}>
        <DialogTitle id="form-dialog-title">Deploy IOC</DialogTitle>
        <DialogContent>
          <TextField autoComplete="off" className={classes.textField} id="comment" label="Deployment comment" variant="outlined" fullWidth required/>
          <TextField autoComplete="off" className={classes.textField} id="git" label="Git repository" variant="outlined" defaultValue={init.git || ""} fullWidth required/>
          <TextField autoComplete="off" className={classes.textField} id="version" label="Git reference" variant="outlined" 
              defaultValue={init.version || ""} fullWidth required/>
          <Autocomplete
            className={classes.textField}
            autoHighlight
            id="host"
            options={hosts}
            defaultValue = { init }
            getOptionLabel={option => {console.log(option); return option?.csEntryHost?.fqdn}}
            renderInput={(params) => <TextField {...params} label="host" variant="outlined" required/>}
            onChange={(event, value, reason) => setHost(value)}
            onInputChange={(event, value, reason) => {event && onHostKeyUp(event.nativeEvent)}}
          />
        </DialogContent>
        <DialogActions>
          <Button onClick={handleClose} color="primary">Cancel</Button>
          <Button color="primary" variant="contained" type="submit">Deploy</Button>
        </DialogActions>
      </form>
    </Dialog>
  );
}