import { Button, Snackbar, Typography } from "@material-ui/core";
import { Alert } from "@material-ui/lab";
import React from "react";
import { useGlobalAppBar } from "../navigation/GlobalAppBar/GlobalAppBar";
import { SimpleAccordion } from "../common/Accordion/SimpleAccordion";
import { IOCDetails } from "./IOCDetails";
import { Link } from 'react-router-dom';
import { useIOCService } from "../../api/SwaggerApi";
import { useSnackbar } from 'notistack';
import { LokiPanel } from "../common/Loki/LokiPanel";
import { useHost } from '../../api/SwaggerApi';
import GitRefLink from "./GitRefLink";

export function IOCLiveStatus({ ioc }) {
  useGlobalAppBar(
    "CCCE / IOC Details"
  );

  const liveIOC = { ...ioc };
  liveIOC.host = ioc.activeDeployment.host.host;
  //const hostName = liveIOC.host.split('.', 1)[0];
  const getSubset = (ioc) => {
    const { description, /*status,*/ hasLocalCommits } = ioc;

    console.log(hasLocalCommits);

    return ({
      "Git reference": <GitRefLink ioc={ioc} />,
      description,
      "Deployed on": <Typography><Link to={`/hosts/${ioc.activeDeployment.host.csEntryId}`}>{ioc.activeDeployment.host.host}</Link></Typography>,
      /*"Open IOC host in CSentry": <a href={`https://csentry.esss.lu.se/network/hosts/view/${hostName}`} target="_blank" rel="noreferrer">{`https://csentry.esss.lu.se/network/hosts/view/${hostName}`}</a>,
      "Host status": status?.toLowerCase(),*/
      "IOC Service Controls": <IOCServiceControls ioc={ioc} />,
    })
  };
  const alert = <Alert severity="info">This is the currently deployed version</Alert>;

  const [iocHost] = useHost(liveIOC.activeDeployment?.host.csEntryId);
  function isIocDeployed(ioc) {
    return ((ioc.activeDeployment) && (ioc.active === true))
  }

  return (
    <>
      <IOCDetails ioc={liveIOC} getSubset={getSubset} />
      <SimpleAccordion summary="ProcServLog info" defaultExpanded>
        {iocHost && <LokiPanel host={iocHost} isSyslog={false} iocName={ioc.latestVersion?.namingName} isDeployed={isIocDeployed(ioc)} />}
      </SimpleAccordion>
      <Snackbar open autoHideDuration={6000}>{alert}</Snackbar>
    </>
  );
}

export function IOCServiceControls({ ioc }) {
  const { startIOC, stopIOC/*, restartIOC*/ } = useIOCService(ioc.id);
  const { enqueueSnackbar } = useSnackbar();
  const start = async () => {
    await startIOC();
    enqueueSnackbar(`IOC ${ioc.name} started.`, { variant: "success" })
  }
  const stop = async () => {
    await stopIOC();
    enqueueSnackbar(`IOC ${ioc.name} stopped`, { variant: "success" })
  }
  /*const restart = async () => {
    await restartIOC();
    enqueueSnackbar(`IOC ${ioc.name} restarted`, {variant: "success"})
  }*/
  return (
    <>
      <Button color="secondary" variant="outlined" onClick={stop}>Stop</Button>
      <Button variant="outlined" onClick={start}>Start</Button>
    </>
  )
}