import { Button, Link as MuiLink, Typography } from "@material-ui/core";
import React, { useState } from "react";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { IOCDetails } from "../../components/IOC/IOCDetails";
import { DeployIOC } from "../../components/IOC/DeployIOC";
import { UndeployIOC } from "../../components/IOC/UndeployIOC";
import { SimpleModal } from "../../components/common/SimpleModal/SimpleModal";
import { useUpdateAndDeployIoc, useCreateUndeployment } from "../../api/SwaggerApi";
import GitRefLink from "./GitRefLink";

export function IOCManage({ ioc, getIOC }) {
  const [deployDialogOpen, setDeployDialogOpen] = useState(false);
  const [undeployDialogOpen, setUndeployDialogOpen] = useState(false);

  useGlobalAppBar("CCCE / IOC Details");

  const closeDeployModal = () => {
    setDeployDialogOpen(false);
    getIOC();
    // history.push(window.location.pathname);
  }

  const closeUndeployModal = () => {
    setUndeployDialogOpen(false);
  }

  let content = <></>;
  if (ioc) {
    console.log({ ...ioc });

    const getSubset = (ioc) => {
      ioc = { ...ioc };
      const {
        description,
        // active, 
      } = ioc;
      const { sourceUrl: git } = ioc.latestVersion;
      const host = ioc.activeDeployment?.host.host;
      return {
        description,
        // active: (active && (ioc.latestVersion.id == ioc.deployedVersion?.id)), 
        git: <Typography><MuiLink href={git} target="_blank" rel="noreferrer">{git}</MuiLink></Typography>,
        "Git reference" : <GitRefLink ioc={ioc} />,
        "target host": host,
      };
    };

    const formInit = {
      name: ioc.name,
      description: ioc.description,
      version: ioc.latestVersion.sourceVersion,
      git: ioc.latestVersion.sourceUrl,
    };

    if (ioc.activeDeployment) {
      formInit.csEntryHost = {
        fqdn: ioc.activeDeployment.host.host,
        id: ioc.activeDeployment.host.csEntryId,
      }
    }

    content = (
      <>
        <IOCDetails ioc={ioc} getSubset={getSubset} alert={alert}
          buttons={
            <>
              <Button variant="contained" color="secondary" onClick={() => { setDeployDialogOpen(true) }}>Deploy IOC</Button>
              {ioc.activeDeployment ? 
                <Button variant="contained" color="secondary" style={{ marginRight: 20 }} onClick={() => { setUndeployDialogOpen(true) }}>Undeploy IOC</Button> :
                <></> 
              }
            </>
          } />
        <SimpleModal open={deployDialogOpen} setOpen={setDeployDialogOpen}>
          <DeployIOC open={deployDialogOpen} setOpen={setDeployDialogOpen} submitCallback={closeDeployModal} init={formInit} hook={useUpdateAndDeployIoc.bind(null, ioc.id)} />
        </SimpleModal>
        <SimpleModal open={undeployDialogOpen} setOpen={setUndeployDialogOpen}>
          <UndeployIOC open={undeployDialogOpen} setOpen={setUndeployDialogOpen} submitCallback={closeUndeployModal} ioc={ioc} hook={useCreateUndeployment} />
        </SimpleModal>
      </>
    );
  }

  return (
    <>
      {content}
    </>
  );

}