import React from 'react';
import { CustomTable } from "../common/table/CustomTable";
import { Box, Grid } from "@material-ui/core";
import { useHistory } from 'react-router-dom';
import { SearchBoxFilter } from '../common/SearchBoxFilter/SearchBoxFilter';
import { IOCStatusIcon } from './IOCIcons';
import { parseHostUrl } from '../common/Helper';
import IOCGitExporter from './IOCGitExporter';

const columns = [
  { id: "status", label: 'Status', width: '8%' },
  { id: "namingName", label: 'IOC name', width: '20%', sortable: true },
  { id: "host", label: 'Host', width: '15%', sortable: true },
  { id: 'network', label: 'Network', width: '15%', sortable: true },
  { id: "version", label: 'Git reference', width: '28%', sortable: true },
]

const hostDetailsColumns = [
  { id: "status", label: 'Status', width: '8%' },
  { id: "name", label: 'Name', width: '30%', sortable: true },
  { id: "version", label: 'Git reference', width: '62%', sortable: true },
]

function createTableRowForHostDetails(ioc) {
  const { id, name, namingName, version } = ioc;

  return {
    id: id,
    status: 
      <Box display="flex" justifyContent="center" p={2} m={1}>
        <IOCStatusIcon ioc={ioc} />
      </Box>,
    name: namingName ?? name,
    version: version,
  };
}

function createTableRow(ioc) {
  const { id, namingName, version, host, dirty,  hasLocalCommits} = ioc;
  const {hostName, network} =  host ? parseHostUrl(host) : {hostName: null, network: null};

  return {
    id: id,
    status: 
    <Grid container direction="column" justifyContent="center" alignItems="center">
      <IOCStatusIcon ioc={ioc} />

      <IOCGitExporter isDirty={dirty} hasLocalCommits={hasLocalCommits} shrink='25%'/>
    </Grid>,
    namingName: namingName ?? "---",
    version: version,
    host: (hostName || "---"),
    network: (network || "---"),
  };
}

export function IOCTable({ iocs, forHostDetails=false }) {
  const history = useHistory();

  const onRowClicked = (id) => {
    history.push(`/iocs/${id}`);
  };

  return (
    <>
    {
      forHostDetails ?
      <CustomTable columns={hostDetailsColumns} rows={iocs.map(ioc => createTableRowForHostDetails(ioc))} handleRowClick={onRowClicked} />
      :
      <CustomTable columns={columns} rows={iocs.map(ioc => createTableRow(ioc))} handleRowClick={onRowClicked} />
    }
    </>
  );
}

export function SearchableIOCTable({ iocs, setQuery, forHostDetails }) {
  const filter = (search) => {
    setQuery(search.toLowerCase());
    return (ioc) => {
      return true;
    }
  }

  const renderFilteredIOCs = (filteredIOCs) => <IOCTable iocs={filteredIOCs} forHostDetails={forHostDetails}/>;

  return (
    <SearchBoxFilter items={iocs} filter={filter} render={renderFilteredIOCs} />
  );
}
