import React, { useState, useEffect } from "react";
import moment from 'moment';

export function formatToList(items) {

    if(!items) return null;

    return (
        <ul style={{ padding: 0 }}>
            {items.map((item) => (
                <li style={{ listStylePosition: 'inside' }} key={item}>{item}</li>
            ))}
        </ul>
    )
}

export function searchInArray(array, searchText) {
    if(array) {
        const found = array.find(element => element.toLowerCase().includes(searchText) );

        return found;
    }

    return false;
}

export const formatDate = (value) => {
    if (value) {
      return moment(value).format('DD/MM/YYYY HH:mm:ss');
    }
    return null;
}

function getWindowDimensions() {
  const { innerWidth: width, innerHeight: height } = window;
  return {
    width,
    height
  };
}

export function useWindowDimensions() {
  const [windowDimensions, setWindowDimensions] = useState(getWindowDimensions());

  useEffect(() => {
    function handleResize() {
      setWindowDimensions(getWindowDimensions());
    }

    window.addEventListener('resize', handleResize);
    return () => window.removeEventListener('resize', handleResize);
  }, []);

  return windowDimensions;
}

export function parseHostUrl(url) {
  const hostName = url.split('.', 2)[0];
  const network = url.split('.', 2)[1];

  return {hostName: hostName, network: network.includes('cslab') ? "CSLab" : (network.includes('tn') ? "TN" : null)};
}