import React from "react";
import { createContext, useEffect } from "react";
import { useDeploymentById } from '../../../api/SwaggerApi';

export const notificationContext = createContext({ deploymentNotifications: [], watchDeployment: ()=>{}, clearAll: ()=>{} });
export const WATCHED_DEPLOYMENT_IDS = "WATCHED_DEPLOYMENT_IDS";
export const DEPLOYMENT_NOTIFICATIONS = "DEPLOYMENT_NOTIFICATIONS";
const DEPLOYMENT_STATUS_POLL_INTERVAL = 3000;

export function NotificationProvider({ children }) {
  const [deployment, getDeployment] = useDeploymentById();
  
  const watchDeployment = (watchedDeploymentId) => {
    var watchedIds = JSON.parse(localStorage.getItem(WATCHED_DEPLOYMENT_IDS));
    localStorage.setItem(WATCHED_DEPLOYMENT_IDS, JSON.stringify(watchedIds ? [watchedDeploymentId].concat(watchedIds) : [watchedDeploymentId]));
  }  

  function removeDeploymentId(id) {
    var watchedIds = JSON.parse(localStorage.getItem(WATCHED_DEPLOYMENT_IDS));
    if (watchedIds) {
      var idsAfterRemove = watchedIds.filter(function(item){ 
          return item !== id; 
      });
      if (idsAfterRemove.length === 0) {
        localStorage.removeItem(WATCHED_DEPLOYMENT_IDS);
      } else {
        localStorage.setItem(WATCHED_DEPLOYMENT_IDS, JSON.stringify(idsAfterRemove));
      }
    }
  }

  const clearAll = () => {
    localStorage.removeItem(WATCHED_DEPLOYMENT_IDS);
    localStorage.removeItem(DEPLOYMENT_NOTIFICATIONS);
  } 

  function deploymentNotifications() {
    var notifications = JSON.parse(localStorage.getItem(DEPLOYMENT_NOTIFICATIONS));
    if (!notifications) {
      return [];
    }
    return notifications;
  }

  function setDeploymentNotifications(notifications) {
    localStorage.setItem(DEPLOYMENT_NOTIFICATIONS, JSON.stringify(notifications));
  }
 
  useEffect(() => {
    function getDeploymentIds() {
      var ids = JSON.parse(localStorage.getItem(WATCHED_DEPLOYMENT_IDS));
      return ids ? ids.map(Number) : [];
    }

    function appendNotifications(notification) {
      if (!deploymentNotifications().includes(notification)) {
        setDeploymentNotifications([notification].concat(deploymentNotifications()));
      }
    }

    const interval = setInterval(() => {
      const deploymentIds = getDeploymentIds();
      for (const deploymentId of deploymentIds) {
        getDeployment(deploymentId);
        if(deployment?.id === deploymentId && deployment?.status === "QUEUED") {
          appendNotifications("Deployment (" + deployment.id + ") for " + deployment.iocName + " is queued");
        } else if(deployment?.id === deploymentId && deployment?.status === "PENDING") {
          appendNotifications("Deployment (" + deployment.id + ") for " + deployment.iocName + " is pending");
        } else if(deployment?.id === deploymentId && deployment?.status === "RUNNING") {
          appendNotifications("Deployment (" + deployment.id + ") for " + deployment.iocName + " is running");
        } else if(deployment?.id === deploymentId && deployment?.status === "FAILED") {
          appendNotifications("Deployment (" + deployment.id + ") for " + deployment.iocName + " is failed");
          removeDeploymentId(deployment.id);
        } else if(deployment?.id === deploymentId && deployment?.status === "SUCCESSFUL") {
          appendNotifications("Deployment (" + deployment.id + ") for " + deployment.iocName + " is successful");
          removeDeploymentId(deployment.id);
        }
      }
    }, DEPLOYMENT_STATUS_POLL_INTERVAL);
    return () => clearInterval(interval);
  }, [deployment, getDeployment]);

  return (
    <notificationContext.Provider value={{ deploymentNotifications, watchDeployment, clearAll }}>
      {children}
    </notificationContext.Provider>
  );
}