import React from 'react';
import PropTypes from 'prop-types';
import { Paper } from '@material-ui/core';
import { DataTable } from 'primereact/datatable';
import { Column } from 'primereact/column';
import 'primeicons/primeicons.css';
import 'primereact/resources/themes/mdc-light-indigo/theme.css';
import 'primereact/resources/primereact.css';
import 'primeflex/primeflex.css';
import './CustomTable.css';

export function CustomTable(props) {
  const {columns, rows, handleRowClick} = props;

  const dynamicColumns = columns.map((col,i) => {
        return <Column key={col.id} field={col.id} header={col.label} style={{width: col.width}} body={col.body} sortable={col.sortable}/>;
    });

  const handleClick = (event) => {
    handleRowClick(event.data.id);
  };

  return (
    <div className="ccce-custom-table">
      <Paper>
        <DataTable
          className="p-ccce-custom-table"
          value={rows}
          stripedRows
          scrollable 
          scrollHeight="540px"
          resizableColumns 
          columnResizeMode="fit"
          paginator
          paginatorTemplate="CurrentPageReport FirstPageLink PrevPageLink PageLinks NextPageLink LastPageLink RowsPerPageDropdown"
          currentPageReportTemplate="Showing {first} to {last} of {totalRecords}" rows={10} rowsPerPageOptions={[10,20,50]}
          rowHover
          onRowClick={(event) => handleClick(event)}
        >
          {dynamicColumns}
        </DataTable>
      </Paper>
    </div>
  );
}

CustomTable.propTypes = {
  columns: PropTypes.arrayOf(PropTypes.shape({id: PropTypes.string.isRequired})).isRequired,
  rows: PropTypes.array.isRequired,
  handleRowClick: PropTypes.func.isRequired,
};