import React, { useEffect, useState } from 'react';
import { Grid, Typography, Button, Card, CardContent, CardActions, Container, Link as MuiLink} from '@material-ui/core';
import { makeStyles, createMuiTheme } from '@material-ui/core/styles';
import { DeploymentStepper } from "./DeploymentStepper"
import { KeyValueTable } from "../common/KeyValueTable/KeyValueTable";
import { SimpleAccordion } from "../common/Accordion/SimpleAccordion";
import { DeploymentBadge } from './DeploymentBadge';
import { DeploymentJobOutput } from './DeploymentJobOutput';
import { Alert } from '@material-ui/lab';
import { Link } from 'react-router-dom';
import { formatDate } from '../common/Helper';

const useStyles = makeStyles({
  root: {
    width: '100%'
  },
  actions: {
    justifyContent: 'flex-end',
  },
});

export function DeploymentDetails({ deployment, getDeployment, onDeploymentStart, startButtonDisabled }) {
  const [alert, setAlert] = useState((<Alert severity="info" variant="standard">The deployment is still in progress.</Alert>));
  const [updateOutput, setUpdateOutput] = useState(true);

  useEffect(() => {
    if (deployment) {
      if (!(["successful", "failed"].includes(deployment.status.toLowerCase()))) {
        if (["queued", "pending"].includes(deployment.status.toLowerCase())) {
          setAlert(<Alert severity="info" variant="standard">The deployment is queued.</Alert>);
        } else if (["running"].includes(deployment.status.toLowerCase())) {
          setAlert(<Alert severity="info" variant="standard">The deployment is running.</Alert>);
        }
        setTimeout(getDeployment, 5000);
        setUpdateOutput(true);
      }
      else {
        setUpdateOutput(false);
        let alert = (deployment.status.toLowerCase() === "failed") ?
          (<Alert severity="error" variant="standard">The deployment had failures.</Alert>)
          : (<Alert severity="success" variant="standard"><Container>The deployment was successful.</Container></Alert>);
        setAlert(alert);
      }
    }
  }, [deployment, getDeployment]);

  const deploymentDetails = {
    "Git reference": deployment.version.sourceVersion,
    host: <Typography><Link to={`/hosts/${deployment.host.csEntryId}`}>{deployment.host.host}</Link></Typography>,
    repository: <Typography><MuiLink href={deployment.version.sourceUrl} target="_blank" rel="noreferrer">{deployment.version.sourceUrl}</MuiLink></Typography>,
    "start time": deployment.startDate ? formatDate(deployment.startDate) : "-",
    "end time": deployment.endDate ? formatDate(deployment.endDate) : "-"
  }

  const theme = createMuiTheme();
  const classes = useStyles(theme);

  return (
    <Grid container spacing={1}>
      <Grid item xs={12} md={12}>
        <SimpleAccordion defaultExpanded summary={<DeploymentBadge deployment={deployment} />}>
          <KeyValueTable obj={deploymentDetails} variant="overline" />
        </SimpleAccordion>
      </Grid>
      <Grid item xs={12} md={12}>
        <Card className={classes.root}>
          <CardContent>
            <div className={classes.stepperContainer}>
              <DeploymentStepper activeStep={["created", "pending", "running", "successful"].indexOf(deployment.status.toLowerCase())} deploymentStatus={deployment.status}
                deploymentStart={deployment.startDate} />
            </div>
          </CardContent>
          {deployment.manual &&
            <CardActions className={classes.actions}>
              <Button variant="contained" color="primary" onClick={onDeploymentStart} disabled={startButtonDisabled}>
                Start deployment
              </Button>
            </CardActions>
          }
        </Card>
      </Grid>
      {alert && <Grid item xs={12}>
          {alert}
        </Grid>}
      <Grid item xs={12} md={12}>
        { deployment.awxJobId ?
          <SimpleAccordion summary="Deployment Job Output" defaultExpanded>
            <DeploymentJobOutput awxJobId={deployment.awxJobId} update={updateOutput} />
          </SimpleAccordion>
          :
          <></>
        }
      </Grid>
    </Grid>
  );
}
