import React, { useRef, useState, useEffect } from 'react';
import { LinearProgress, Typography  } from '@material-ui/core';
import { useDeploymentJob } from '../../api/SwaggerApi';

export function DeploymentJobOutput({ awxJobId, update }) {
  const [deploymentJob, getDeploymentJob] = useDeploymentJob(awxJobId);
  const stdoutRef = useRef(null);
  const [firstTime, setFirstTime] = useState(true);

  useEffect(() => {
    const interval = setInterval(() => {
      if (update) {
        getDeploymentJob();
      }
    }, 5000);
    return () => clearInterval(interval);
  }, [update, getDeploymentJob]);

  useEffect(() => {
    function scrollDown() {
      if (stdoutRef.current) {
        stdoutRef.current.scrollTop = stdoutRef.current.scrollHeight;
        if (firstTime && deploymentJob?.job.started) {
          stdoutRef.current?.parentElement.scrollIntoView(false);
          setFirstTime(false);
        }
      }
    }

    scrollDown();
  }, [deploymentJob, firstTime]);

  return deploymentJob?.job.started ?
    <div style={{
        width: "100%",
      }}>
      <div style={{
        display: "flex",
        alignItems: "center"
      }}>
        <Typography variant="overline">DURATION: </Typography>
        <Typography style={{
            marginLeft: "6px",
          }}>
          {deploymentJob?.job.elapsed.toFixed(0)} s
        </Typography>
      </div>
      <div
        ref={stdoutRef}
        style={{
          overflow: "auto",
          minHeight: "500px",
          maxHeight: "500px",
          width: "100%",
          color: "white",
          backgroundColor: "black",
          paddingLeft: "10px",
          paddingRight: "10px",
        }}
        dangerouslySetInnerHTML={{ __html: deploymentJob.stdout }}
      />
    </div>
    : <div style={{ width: "100%" }}><LinearProgress color="primary" /></div>
}