import React from 'react';
import { List, ListItem, Paper, } from "@material-ui/core";
import { Link } from 'react-router-dom';
import { SearchBoxFilter } from "../common/SearchBoxFilter/SearchBoxFilter";
import { DeploymentBadge } from "./DeploymentBadge";

export function DeploymentListItem({ deployment }) {
  return (
    <Paper>
      <ListItem button component={Link} to={deployment.url}>
        <DeploymentBadge deployment={deployment} />
      </ListItem>
    </Paper>
  );
}

export function DeploymentsList({deployments}) {
  return (
    <List>
      {deployments && deployments.map((deployment) => {
        deployment.url=`/deployments/${deployment.id}`;
        return (
          <DeploymentListItem key={deployment.id} deployment={deployment} />
        );
      })}
    </List>
  );
}

export function SearchableDeploymentsList({ deployments, setQuery }) {
  const filter = (search) => {
    setQuery(search.toLowerCase());
    return (item) => {
      return true;
    }
  }

  const renderFilteredItems = (filteredDeployments) => {
    return (
        <DeploymentsList deployments={filteredDeployments}/>
      );
  }

  return (
    <SearchBoxFilter items={deployments} filter={filter} render={renderFilteredItems}/>
  );
}