import React from 'react';
import { CustomTable } from "../common/table/CustomTable";
import { Box } from "@material-ui/core";
import { CheckCircleOutline, ErrorOutline, RotateRightOutlined, ScheduleOutlined } from "@material-ui/icons";
import { SearchBoxFilter } from "../common/SearchBoxFilter/SearchBoxFilter";
import { theme } from "../../Theme";
import { DeploymentStatusIcon } from './DeploymentIcons';
import { useHistory } from 'react-router';
import { formatDate, parseHostUrl } from '../common/Helper';

const formatDeploymentDate = (value) => {
    if (value) {
      return formatDate(value);
    }
    return "Not started yet";
}

const dateTemplate = (rowData) => {
    return formatDeploymentDate(rowData.start);
}

const columns = [
  { id: 'status', label: 'Status', width: '5%'},
  { id: 'ioc', label: 'IOC Name', width: '15%', sortable: true },
  { id: 'version', label: 'Git reference', width: '24%', sortable: true },
  { id: 'host', label: 'Host', width: '13%', sortable: true },
  { id: 'network', label: 'Network', width: '13%', sortable: true },
  { id: 'user', label: 'User', width: '15%', sortable: true },
  { id: 'start', label: 'Start date', width: '15%', body: dateTemplate, sortable: true }
];

function createTableRow(deployment) {
  console.log(deployment);
  const {hostName, network} =  deployment.host ? parseHostUrl(deployment.host.host) : {name: null, network: null};

  return { 
    id:deployment.id, 
    status: 
     <Box display="flex" justifyContent="center" p={2} m={1}>
      <DeploymentStatusIcon status={deployment.status}/>
    </Box>,
    ioc: deployment.iocName,
    version: deployment.version.sourceVersion, 
    host: hostName,
    network: network, 
    user: deployment.createdBy,
    start: deployment.startDate,
  };
}

export const deploymentStatusIcons = {
  "success": <CheckCircleOutline />,
  "failed": <ErrorOutline />,
  "running": <RotateRightOutlined />,
  "scheduled": <ScheduleOutlined />,
}

export const deploymentStatusColors = {
  "success": theme.palette.status.ok,
  "failed": theme.palette.status.fail,
  "running": theme.palette.status.progress,
  "scheduled": theme.palette.status.neutral,
}

export function DeploymentsTable({deployments}) {
  const history = useHistory();

  const onRowClicked = (id) => {
    history.push(`/deployments/${id}`);
  };

  return (
    <CustomTable columns={columns} rows={deployments.map(deployment => createTableRow(deployment))} handleRowClick={onRowClicked}/>
  );
}

export function SearchableDeploymentsTable({ deployments, setQuery }) {
  const filter = (search) => {
    setQuery(search.toLowerCase());
    return (item) => {
      return true;
    }
  }

  const renderFilteredItems = (filteredDeployments) => {
    return (
        <DeploymentsTable deployments={filteredDeployments}/>
      );
  }

  return (
    <SearchBoxFilter items={deployments} filter={filter} render={renderFilteredItems}/>
  );
}