import React, { useState } from 'react';
import {
    Checkbox,
    Table,
    TableBody,
    TableCell,
    Button,
    Grid,
    Link,
    Paper,
    TableRow,
    TableContainer
} from '@material-ui/core';
import { withStyles } from '@material-ui/core/styles';
import { TableHead } from '@material-ui/core';
import { formatToList } from '../common/Helper';

export default function HostInterfaces() {

    //demo dummy data
    let tmpIntF = [{
        name: 'test.host.esss.lu.se',
        isMain: false,
        description: 'this is a test host',
        cnames: [],
        ip: '127.0.0.1',
        mac: '12:58:34:bc:ef:a1',
        network: { name: 'One network', link: 'https://csentry.esss.lu.se/network/hosts/view/mpsid-ipc-01' }
    },
    {
        name: 'test5.esss.lab.lu.se',
        isMain: false,
        description: 'a lab equipment host',
        cnames: ['labnet', 'cnet'],
        ip: '16.32.54.2',
        mac: '9b:e5:ff:3a:bb:c0',
        network: { name: 'Another network', link: 'https://csentry.esss.lu.se/network/hosts/view/mpsid-ipc-01' }
    },
    {
        name: 'technetwork.host.com',
        isMain: false,
        description: 'tester thing',
        cnames: ['tst123'],
        ip: '192.168.3.5',
        mac: '71:bc:3a:de:b2:11',
        network: { name: 'Network for Tests', link: 'https://csentry.esss.lu.se/network/hosts/view/mpsid-ipc-01' }
    },
    {
        name: 'prod.network.esss.lu.se',
        isMain: true,
        description: 'this is the prod env',
        cnames: ['prod'],
        ip: '172.18.4.22',
        mac: 'ac:52:f2:4e:cc:21',
        network: { name: 'Prod network', link: 'https://csentry.esss.lu.se/network/hosts/view/mpsid-ipc-01' }
    }
    ];

    const [interfaces, setInterfaces] = useState(null);

    //fill state with the dummy data
    const testFillData = () => {
        setInterfaces(tmpIntF);
    }
     

    //stlyes
    //teble header
    const StyledTableCell = withStyles((theme) => ({
        head: {
            backgroundColor: '#e0e0e0',
            color: theme.palette.common.black,
            fontWeight: 'bold',
        },
        body: {
            fontSize: 14,
        },
    }))(TableCell);

    //table body
    const StyledTableRow = withStyles((theme) => ({
        root: {
            '&:nth-of-type(odd)': {
                backgroundColor: '#e3f2fd',
            },
        },
    }))(TableRow);

    return (
        <Grid container>
            <Grid item xs={12} sm={6} md={8} lg={12}>
                <Button variant="contained" color="primary" onClick={testFillData}>Load Data</Button>
                <TableContainer component={Paper}>
                    <Table size="small" key="CSEntryInterfacesTable">
                        <TableHead>
                            <TableRow>
                                <StyledTableCell >Name</StyledTableCell>
                                <StyledTableCell >Network</StyledTableCell>
                                <StyledTableCell >IP</StyledTableCell>
                                <StyledTableCell >Description</StyledTableCell>
                                <StyledTableCell >CNames</StyledTableCell>
                                <StyledTableCell >Is Main?</StyledTableCell>
                                <StyledTableCell >Mac</StyledTableCell>
                            </TableRow>
                        </TableHead>

                        <TableBody>
                            {interfaces?.map((row) => (
                                <StyledTableRow align="left" key={row.name}>

                                    <TableCell >{row.name}</TableCell>
                                    <TableCell >
                                        <Link href={row.network.link} target="_blank" rel="noreferrer">
                                            {row.network.name}
                                        </Link>
                                    </TableCell>
                                    <TableCell >{row.ip}</TableCell>
                                    <TableCell >{row.description}</TableCell>
                                    <TableCell >{formatToList(row.cnames)}</TableCell>
                                    <TableCell >
                                        <Checkbox disabled checked={row.isMain} name="isIocCheckBox" />
                                    </TableCell>
                                    <TableCell >{row.mac}</TableCell>
                            
                                </StyledTableRow>
                            )
                            )}
                        </TableBody>
                    </Table>
                </TableContainer>
            </Grid>
        </Grid>

    );
}