import React from "react";
import {
    List,
    ListItem,
    Paper
} from '@material-ui/core';

import { Link } from 'react-router-dom';
import { SearchBoxFilter } from "../common/SearchBoxFilter/SearchBoxFilter";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { HostBadge } from './HostBadge';

export function HostListItem({ host }) {
    return (
        <Paper>
            <ListItem button component={Link} to={host.url}>
                <HostBadge host={host} />
            </ListItem>
        </Paper>
    );
}

export function HostLists({ hosts }) {
    return (
        <List>
            {hosts && hosts.map((host) => {
                host.url = `/hosts/${host.csEntryHost.id}`;
                return (
                    <HostListItem key={host.csEntryHost.id} host={host} />
                );
            })}
        </List>
    );
}

export default function HostList({hosts, setQuery}) {
    useGlobalAppBar(
        "Hosts"
      );

    const filter = (search) => {
        setQuery(search.toLowerCase());
        return (host) => {
            return true;
        }
    }

    const renderFilteredHosts = (filteredHosts) => <HostLists hosts={filteredHosts} />;

    return (
        <SearchBoxFilter items={hosts} filter={filter} render={renderFilteredHosts} />
    );
}