import React from 'react';
import { Box } from "@material-ui/core";
import { CustomTable } from '../common/table/CustomTable';
import { SearchBoxFilter } from "../common/SearchBoxFilter/SearchBoxFilter";
import { useHistory } from 'react-router-dom';
import { HostStatusIcon } from './HostIcons';


const columns = [
    { id: 'bulb', label: 'Status', width: '10%' },
    { id: 'host', label: 'Host', width: '15%' },
    { id: 'description', label: 'Description', width: '15%' },
    { id: 'network', label: 'Network', width: '15%' },
    { id: 'scope', label: 'Scope', width: '15%' },
    /*{ id: 'user', label: 'User', width: '15%' },*/
    { id: 'deviceType', label: 'Device Type', width: '15%' },
];

export function createRow(hostContainer) {
    const host = hostContainer.csEntryHost;
    return {
        id: host.id,
        bulb: 
          <Box display="flex" justifyContent="center" p={2} m={1}>
            <HostStatusIcon host={hostContainer} />
          </Box>,
        host: host.fqdn,
        description: host.description,
        network: host.interfaces[0]?.network,
        deviceType: host.device_type,
        //user: host.user,
        scope: host.scope,
    };

}


export function HostsTable({ hosts }) {
    const history = useHistory();

    console.log(hosts);

    const onRowClicked = (id) => {
        history.push(`/hosts/${id}`);
    };

    return <CustomTable columns={columns} rows={hosts.map(host => createRow(host))} handleRowClick={onRowClicked} />;
}

export default function HostTable({ hosts, setQuery }) {
    const filter = (search) => {
        setQuery(search.toLowerCase());
        return (hostContainer) => {
            return true;    
        }
    }

    const renderFilteredHosts = (filteredHosts) => <HostsTable hosts={filteredHosts} />;

    return (
        <SearchBoxFilter items={hosts} filter={filter} render={renderFilteredHosts} />
    );
}