import React, { useState } from 'react';
import {
    Accordion,
    AccordionDetails,
    AccordionSummary,
    Link,
    ListItemText,
    Paper,
    List,
    Typography, 
    Table, 
    TableBody,
    TableCell,
    TableContainer,
    TableRow,
    Grid,
    ListItem,
    ListItemIcon
} from "@material-ui/core";

import { withStyles } from '@material-ui/core/styles';
import { formatToList } from '../common/Helper';
import { makeStyles } from '@material-ui/core/styles';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import Grade from '@material-ui/icons/Grade';

//demo dummy data
let tmpIntF = [{
    id: 0,
    name: 'test.host.esss.lu.se',
    isMain: true,
    description: 'this is a test host',
    cnames: [],
    ip: '127.0.0.1',
    mac: '12:58:34:bc:ef:a1',
    network: { name: 'One network', link: 'https://csentry.esss.lu.se/network/hosts/view/mpsid-ipc-01' }
},
{
    id: 1,
    name: 'test5.esss.lab.lu.se',
    isMain: false,
    description: 'a lab equipment host',
    cnames: ['labnet', 'cnet'],
    ip: '16.32.54.2',
    mac: '9b:e5:ff:3a:bb:c0',
    network: { name: 'Another network', link: 'https://csentry.esss.lu.se/network/hosts/view/mpsid-ipc-01' }
},
{
    id: 2,
    name: 'technetwork.host.com',
    isMain: false,
    description: 'tester thing',
    cnames: ['tst123'],
    ip: '192.168.3.5',
    mac: '71:bc:3a:de:b2:11',
    network: { name: 'Network for Tests', link: 'https://csentry.esss.lu.se/network/hosts/view/mpsid-ipc-01' }
},
{
    id: 3,
    name: 'prod.network.esss.lu.se',
    isMain: false,
    description: 'this is the prod env',
    cnames: ['prod'],
    ip: '172.18.4.22',
    mac: 'ac:52:f2:4e:cc:21',
    network: { name: 'Prod network', link: 'https://csentry.esss.lu.se/network/hosts/view/mpsid-ipc-01' }
}
];

//stlyes
//table body
const StyledTableRow = withStyles((theme) => ({
    root: {
        '&:nth-of-type(odd)': {
            backgroundColor: '#e3f2fd',
        },
    },
}))(TableRow);

//accordion
const useStyles = makeStyles((theme) => ({
    parentWrapper: {
      width: '100%',
      
      '&> :nth-child(odd)':{
        '&>div':{
          backgroundColor: theme.palette.action.hover
        }
      },
    },
  }));

export function itemIcon({ isMain }) {
    return isMain ? <Grade /> : null;
}

export function listItem(interFace) {
    return (interFace.isMain ?
        <ListItemText primary={<Typography variant="h6" inset="true"
            style={{ fontWeight: 'bold', textShadow: '2px 2px 3px' }}>{interFace.name}</Typography>}
            secondary={<Typography
                style={{ fontWeight: 'bold', textShadow: '2px 2px 3px'}}>{interFace.network.name}</Typography>}></ListItemText> :
        <ListItemText primary={interFace.name}
            secondary={interFace.network.name} ></ListItemText>);
}

export default function InterfaceAccordion() {

    const [interfaces] = useState(tmpIntF);
    const classes = useStyles();

    return (
        <Grid container direction="column">
            <Grid item xs={12} sm={6} md={12} className={classes.parentWrapper}>
                {interfaces?.map((interFace, index) => (
                    <Accordion square key={interFace.id}>
                        <AccordionSummary expandIcon={<ExpandMoreIcon />}>
                            <List>
                                <ListItem>
                                <ListItemIcon>
                                        {itemIcon(interFace)}
                                    </ListItemIcon>
                                    {listItem(interFace)}
                                    
                                </ListItem>
                            </List>
                        </AccordionSummary>
                        <AccordionDetails>

                            <TableContainer component={Paper}>
                                <Table size="small">
                                    <TableBody >
                                        <StyledTableRow align="left" >
                                            <TableCell ><strong>Network:</strong></TableCell>
                                            <TableCell >
                                                <Link href={interFace.network.link} target="_blank" rel="noreferrer">
                                                    {interFace.network.name}
                                                </Link>
                                            </TableCell>
                                        </StyledTableRow>

                                        <StyledTableRow align="left">
                                            <TableCell ><strong>IP:</strong></TableCell>
                                            <TableCell >{interFace.ip}</TableCell>
                                        </StyledTableRow>

                                        <StyledTableRow align="left">
                                            <TableCell ><strong>Description:</strong></TableCell>
                                            <TableCell >{interFace.description}</TableCell>
                                        </StyledTableRow>

                                        <StyledTableRow align="left">
                                            <TableCell ><strong>CNames:</strong></TableCell>
                                            <TableCell >{formatToList(interFace.cnames)}</TableCell>
                                        </StyledTableRow>

                                        <StyledTableRow align="left">
                                            <TableCell ><strong>MAC:</strong></TableCell>
                                            <TableCell >{interFace.mac}</TableCell>
                                        </StyledTableRow>
                                    </TableBody>
                                </Table>
                            </TableContainer>

                        </AccordionDetails>
                    </Accordion>
                ))}

            </Grid>
        </Grid>
    );
}