import React, { createContext, useContext, useEffect, useState } from "react";
import {
  AppBar,
  Avatar,
  Button,
  IconButton,
  ListItem,
  ListItemIcon,
  ListItemText,
  makeStyles,
  Toolbar,
  Typography,
  Menu,
  MenuItem,
  Tooltip,
  Badge,
  Popover,
  Grid,
  List,
  Box,
  Divider,
  useTheme
} from "@material-ui/core";
import { withStyles } from '@material-ui/core/styles';
import { /*DesktopMac, Launch,*/ LockOpen, Home, /*PanoramaFishEye,*/Assignment, /*Tune,*/ Storage, TrendingUp } from "@material-ui/icons";
import HelpIcon from '@material-ui/icons/Help';
import { DeploymentStatusIcon } from "../../deployments/DeploymentIcons";
import DeleteIcon from '@material-ui/icons/Delete';
import NotificationsIcon from '@material-ui/icons/Notifications';
import { MenuDrawer } from "../Menu/MenuDrawer";
import { Link } from "react-router-dom";
import { userContext } from "../../../api/SwaggerApi";
import { notificationContext } from "../../common/notification/Notifications";
import { useWindowDimensions } from "../../common/Helper";
import { CCCEControlSymbol } from '../../../icons/CCCEControlSymbol';

const useStyles = makeStyles((theme) => ({
  root: {
    flexGrow: 1,
    paddingBottom: theme.spacing(2),
  },
  appBar: {
    zIndex: 1250 // fixme: a hack to make the appBar stay on top of the drawer, should be between 1201 - 1299
  },
  menuButton: {
    marginRight: theme.spacing(2),
  },
  helpDivider: {
    marginTop: theme.spacing(5),
  },
  title: {
    flexGrow: 1,
  },
  menuIcon: {
    marginLeft: theme.spacing(1),
  },
  typography: {
      padding: theme.spacing(2),
  },
  notificationButton: {
      marginRight: theme.spacing(2),
  },
  content: {
    marginTop: theme.spacing(1),
  },
  notificationList: {
    overflow: 'auto',
    maxHeight: 360,
  },
}));

const StyledMenu = withStyles({
  paper: {
    border: '1px solid #d3d4d5',
  },
})((props) => (
  <>
  <div style={{ ...props.theme.mixins.toolbar }} />
  <Menu
    elevation={0}
    getContentAnchorEl={null}
    anchorOrigin={{
      vertical: 'bottom',
      horizontal: 'center',
    }}
    transformOrigin={{
      vertical: 'top',
      horizontal: 'center',
    }}
    {...props}
  />
  </>
));

const StyledMenuItem = withStyles((theme) => ({
  root: {
    '&:focus': {
      backgroundColor: theme.palette.common.gray,
      '& .MuiListItemIcon-root, & .MuiListItemText-primary': {
        color: theme.palette.common.black,
      },
    },
  },
}))(MenuItem);

export function ButtonAppBar({ homeUrl, homeClick, title, button, profileButton, notificationsButton }) {
  const classes = useStyles();

  return (
    <div className={classes.root}>
      <AppBar position="fixed" className={classes.appBar}>
        <Toolbar>
          <IconButton edge="start" component={Link} to={homeUrl} onClick={homeClick} className={classes.menuButton} color="inherit" aria-label="menu">
            <Home />
          </IconButton>
          <Typography variant="h1" className={classes.title} noWrap>
            {title}
          </Typography>
          {button}
          {notificationsButton}
          {profileButton}
        </Toolbar>
      </AppBar>
    </div>
  );
}


const defaultButton = <Button color="inherit">Login</Button>;
const defaultTitle = "CCCE"
export const GlobalAppBarContext = createContext({
  button: defaultButton,
  title: defaultTitle,
  setButton: () => { console.log("default GlobalAppBarContext.setButton does nothing.") },
  setTitle: () => { console.log("default GlobalAppBarContext.setTitle does nothing.") }
});

function MenuListItem({ selectedUrl, handleListItemClick, url, icon, text, tooltip }) {
  const classes = useStyles();
  const currentUrl = `${window.location}`;
  console.log(currentUrl);
  return (
    <>
    { url.includes("help") ? <Divider className={classes.helpDivider}/> : <></>}
    <Tooltip title={tooltip ? text : ""} placement="right" arrow>
      <ListItem button component={Link} to={url} selected={currentUrl.endsWith(url)}
        onClick={(event) => handleListItemClick(event, url)}>
        <ListItemIcon className={classes.menuIcon}>{icon}</ListItemIcon>
        <ListItemText primary={text} primaryTypographyProps={{variant: "h5"}}/>
      </ListItem>
    </Tooltip>
    </>
  );
}

function MenuListItems({ menuItems, selectedUrl, handleListItemClick, drawerOpen }) {
  return (
    <>
      {menuItems.map(({ text, url, icon }, index) => (
        <MenuListItem key={text} tooltip={!drawerOpen} selectedUrl={selectedUrl} handleListItemClick={handleListItemClick} url={url} icon={icon} text={text}/>
      ))}
    </>
  );
}

export function UserInfo({ user }) {
  console.log(user);
  return (
    <ListItem>
      <ListItemIcon>
        <Avatar src={user.avatar} variant="rounded" />
      </ListItemIcon>
      <ListItemText primary={user.fullName} secondary={user.email} />
    </ListItem>
  );
}

export function ProfileMenu() {
  const theme = useTheme();
  const { user, logout } = useContext(userContext);
  const [anchorEl, setAnchorEl] = useState(null);

  const handleClick = (event) => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };

  return (
    <>
      <Avatar src={user.avatar} variant="circular" onClick={handleClick} aria-controls="profile-menu"
                  aria-haspopup="true"/>
      <StyledMenu
        id="profile-menu"
            anchorEl={anchorEl}
            keepMounted
            open={Boolean(anchorEl)}
            onClose={handleClose}
            theme={theme}
          >
        <StyledMenuItem onClick={() => {handleClose(); logout();}}>
          <ListItemIcon>
            <LockOpen fontSize="small" />
          </ListItemIcon>
          <ListItemText primary="Logout" primaryTypographyProps={{variant: "h5"}} />
        </StyledMenuItem>
      </StyledMenu>
    </>
  );
}

export function NotificationMenu() {
  const [anchorEl, setAnchorEl] = useState(null);
  const classes = useStyles();
  const {deploymentNotifications, clearAll} = useContext(notificationContext);

  const handleClick = (event) => {
    if (deploymentNotifications().length > 0) {
      setAnchorEl(event.currentTarget);
    }
  };

  const handleClose = () => {
    setAnchorEl(null);
  };

  function statusFromNotification(text) {
    const lowerText = text.toLowerCase();

    if(lowerText.includes("pending")) {
      return "pending";
    } else if(lowerText.includes("queued")) {
      return "queued";
    } else if(lowerText.includes("running")) {
      return "running";
    } else if(lowerText.includes("successful")) {
      return "successful";
    } else if(lowerText.includes("failed")) {
      return "failed";
    }
  }

  return (
    <>
      <IconButton color="inherit" onClick={handleClick} className={classes.notificationButton}>
        <Badge badgeContent={deploymentNotifications().length} color="secondary">
          <NotificationsIcon />
        </Badge>
      </IconButton>
      <Popover
        open={Boolean(anchorEl)}
        anchorEl={anchorEl}
        onClose={handleClose}
        anchorOrigin={{
          vertical: 'bottom',
          horizontal: 'center',
        }}
        transformOrigin={{
          vertical: 'top',
          horizontal: 'center',
        }}
      >
        <Grid container spacing={0} justify="flex-end">
          <Grid item xs={12}>
            <List className={classes.notificationList}>
            {deploymentNotifications().map((notification) => {
              return (
              <ListItem key={notification}>
                  <ListItemIcon>
                    <DeploymentStatusIcon status={statusFromNotification(notification)} />
                  </ListItemIcon>
                  <Typography>{notification}</Typography>
                </ListItem>
              );
            })}
            </List>
          </Grid>
          <Grid item xs={2}>
            <Box display="flex" justifyContent="flex-end" mx={1} mb={1}>
              <IconButton color="inherit" onClick={() => {clearAll(); handleClose();}}>
                <Tooltip title="Clear all notifications" arrow>
                  <DeleteIcon />
                </Tooltip>
              </IconButton>
            </Box>
          </Grid>
        </Grid>
      </Popover>
    </>
  );
}

export function GlobalAppBar({ children }) {
  const theme = useTheme();
  const classes = useStyles();
  const [button, setButton] = useState(defaultButton);
  const [title, setTitle] = useState(defaultTitle);
  const [value] = useState({ setButton, setTitle });
  const { width } = useWindowDimensions();
  const [drawerOpen, setDrawerOpen] = useState(width > 1730);
  const [selectedUrl, setSelectedUrl] = React.useState("");

  const toggleDrawer = () => {
    setDrawerOpen(!drawerOpen);
  }

  const handleLeftMenuItemClick = (event, url) => {
    setSelectedUrl(url);
  };

  const profile = ProfileMenu();
  const notifications = NotificationMenu();

  const makeLink = (text, url, icon) => ({ text, url, icon });
  const menuItems = [
    makeLink("Explore IOCs", "/iocs", <CCCEControlSymbol/>),
    makeLink("Explore IOC hosts", "/hosts", <Storage />),
    makeLink("Deployment log", "/deployments", <Assignment />),
    makeLink("Statistics", "/statistics", <TrendingUp />),
    makeLink("Help", "/help", <HelpIcon />)
  ]

  return (
    <>
      <ButtonAppBar homeUrl="/home" homeClick={handleLeftMenuItemClick} title={title} button={button} profileButton={profile} notificationsButton={notifications} />
      <MenuDrawer open={drawerOpen} toggleDrawer={toggleDrawer}>
        <MenuListItems menuItems={menuItems} selectedUrl={selectedUrl} 
                       handleListItemClick={handleLeftMenuItemClick} drawerOpen={drawerOpen}/>
      </MenuDrawer>
      <GlobalAppBarContext.Provider value={value}>
        <div style={{ ...theme.mixins.toolbar }} />
        <div className={classes.content}>
        {children}
        </div>
      </GlobalAppBarContext.Provider>
    </>
  );
}

export function useGlobalAppBar(initTitle, initButton) {
  const [button, setButton] = useState(initButton);
  const [title, setTitle] = useState(initTitle);
  const appBar = useContext(GlobalAppBarContext);
  useEffect(() => {
    appBar.setButton(button);
    appBar.setTitle(title);
  }, [appBar, title, button]);
  return { setButton, setTitle };
}