import { Container, Grid, Paper, Tab, Tabs, Typography, IconButton } from "@material-ui/core";
import ArrowBackIcon from '@material-ui/icons/ArrowBack';
import React, { useEffect, useState } from "react";
import { useIOC } from "../../api/SwaggerApi";
import { IOCLiveStatus } from "../../components/IOC/IOCLiveStatus";
import { IOCManage } from "../../components/IOC/IOCManage";
import { useHistory } from "react-router-dom";

export function IOCDetailsView({ match }) {
  const id = parseInt(match.params.id);
  const [selectedTab, setSelectedTab] = useState("Manage IOC");
  const [firstTime, setFirstTime] = useState(true);
  const [ioc, getIOC] = useIOC(id);
  const history = useHistory();
  console.log(ioc);

  const handleTabChange = (event, tab) => {
    setSelectedTab(tab);
  };

  useEffect(() => {
    if (firstTime && ioc && ioc.activeDeployment) {
      setSelectedTab("Live Status");
      setFirstTime(false);
    }
  }, [ioc, firstTime]);

  const handleClick = (event) => {
    history.goBack();
  };

  return (
      <Container style={{paddingBottom: "200px"}}>
        <Paper>
          <Grid container spacing={1}>
            <Grid item xs={1}>
              <IconButton color="inherit" onClick={handleClick}>
                <ArrowBackIcon />
              </IconButton>
            </Grid>
            <Grid item xs={11}>
              <Grid container justify="center">
                <Tabs
                  value={selectedTab}
                  onChange={handleTabChange}
                  indicatorColor="primary"
                  textColor="primary"
                >
                  {ioc && ioc.activeDeployment && <Tab label={<Typography variant="h5">Live Status</Typography>} value="Live Status" />}
                  {ioc && <Tab label={<Typography variant="h5">Manage IOC</Typography>} value="Manage IOC" />}
                </Tabs>
              </Grid>
            </Grid>
            <Grid item xs={12}>
              {selectedTab === "Live Status" && <IOCLiveStatus ioc={ioc} />}
              {selectedTab === "Manage IOC" && <IOCManage ioc={ioc} getIOC={getIOC} />}
            </Grid>
          </Grid>
        </Paper>
      </Container>
  );
}