import { Container, Grid, Hidden, Paper } from "@material-ui/core";
import React, { useState, useEffect } from "react"
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { SearchableIOCList } from "../../components/IOC/IOCList";
import { SearchableIOCTable } from "../../components/IOC/IOCTable";
import { useIOCSearch } from "../../api/SwaggerApi";

export function IOCListView() {
  const [iocs, getIocs] = useIOCSearch();
  const [query, setQuery] = useState();

  useEffect(() => getIocs(`${query}`), [query, getIocs]);

  console.log("rendering Explore IOCs")

  const title = "CCCE / Explore IOCs";
  useGlobalAppBar(title);

  function preProcess(iocs) {
    console.log(iocs);
    const abcIOCs = iocs.sort((a, b) => a.latestVersion.namingName.localeCompare(b.latestVersion.namingName));
    return abcIOCs;
  }

  let content = (
    <>
      <Hidden smUp>
        <SearchableIOCList iocs={preProcess(iocs)} setQuery={setQuery}/>
      </Hidden>
      <Hidden xsDown>
        <SearchableIOCTable iocs={preProcess(iocs)} setQuery={setQuery}/>
      </Hidden>
    </>
  );

  return (
    <Container>
      <Paper>
        <Grid container spacing={1}>
          <Grid item xs={12}>
            {content}
          </Grid>
        </Grid>
      </Paper>
    </Container>
  );
}

