import React, { useContext, useState, useEffect } from 'react';
import { makeStyles } from '@material-ui/core/styles';
import {Paper, Container, Grid, FormControlLabel, Switch, Hidden, Typography } from '@material-ui/core';
import Tabs from '@material-ui/core/Tabs';
import Tab from '@material-ui/core/Tab';
import { SearchableDeploymentsTable } from "../../components/deployments/DeploymentsTable";
import { SearchableDeploymentsList } from "../../components/deployments/DeploymentsList";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { useDeploymentSearch, userContext } from '../../api/SwaggerApi';


const useStyles = makeStyles({
  root: {
    width: '100%'
  },
  formControl: {
    marginLeft: '5px',
    marginRight: '5px',
  }
});

export function DeploymentsView() {
  const classes = useStyles();
  const [deployments, getDeployments] = useDeploymentSearch();
  const [query, setQuery] = useState();
  const [selectedTab, setSelectedTab] = useState(0);
  const [ownOnly, setOwnOnly] = useState(false);
  const {user} = useContext(userContext);

  useEffect(() => getDeployments(`${query}`), [query, getDeployments]);

  console.log(deployments);

  useGlobalAppBar("CCCE / Deployment log");
  
  function performFilter(tab, own, deploymentList) {
    const prefiltered = own ? deploymentList.filter(deployment => deployment.createdBy === user.loginName) : deployments;
    if (tab === 0) {
      return prefiltered;
    }
    else if (tab === 1) {
      return prefiltered.filter(deployment => deployment.status === "RUNNING");
    }
    else if (tab === 2) {
      return prefiltered.filter(deployment => deployment.status !== "RUNNING" && deployment.status !== "QUEUED");
    }
    else if (tab === 3) {
      return prefiltered.filter(deployment => deployment.status === "QUEUED");
    }
  }

  const handleTabChange = (event, tab) => {
    setSelectedTab(tab);
  };

  const handleChangeOwn = (event) => {
    const own = event.target.checked;
    setOwnOnly(own);
  };

  const content = (
    <>
      <Hidden smUp>
        <SearchableDeploymentsList deployments={performFilter(selectedTab, ownOnly, deployments)} setQuery={setQuery}/>
      </Hidden>
      <Hidden xsDown>
        <SearchableDeploymentsTable deployments={performFilter(selectedTab, ownOnly, deployments)} setQuery={setQuery}/>
      </Hidden>
    </>
  );
  

  return (
      <Container className={classes.root}>
        <Paper>
          <Grid container spacing={1} justify="flex-start">
            <Grid item xs={12} md={10}>
              <Tabs
                value={selectedTab}
                onChange={handleTabChange}
                indicatorColor="primary"
                textColor="primary">
                <Tab label={<Typography variant="h5">All</Typography>} />
                <Tab label={<Typography variant="h5">Running</Typography>} />
                <Tab label={<Typography variant="h5">Finished</Typography>} />
                <Tab label={<Typography variant="h5">Queued</Typography>} />
              </Tabs>
            </Grid>
            <Grid item xs={8} md={2}>
              <FormControlLabel className={classes.formControl}
                control={<Switch checked={ownOnly} onChange={handleChangeOwn} />}
                label={<Typography variant="h5">My deployments</Typography>}
              />
            </Grid>
            <Grid item xs={12} md={12}>
              {content}
            </Grid>
          </Grid>
        </Paper>
      </Container>
  );
}
