import { Container, Grid, Hidden, Paper, Button, Box, Typography } from "@material-ui/core";
import React, { useContext, useState, useEffect } from "react";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { SearchableIOCList } from "../../components/IOC/IOCList";
import { CreateIOC } from "../../components/IOC/CreateIOC";
import { SearchableIOCTable } from "../../components/IOC/IOCTable";
import { SimpleModal } from "../../components/common/SimpleModal/SimpleModal";
import { useCreateIOC, useIOCSearch, userContext } from "../../api/SwaggerApi";


export function HomeView() {
  const [iocs, getIocs] = useIOCSearch();
  const [query, setQuery] = useState();
  const [iocFormOpen, setIOCFormOpen] = useState(false);
  const {user} = useContext(userContext);

  useEffect(() => getIocs(`${query}`), [query, getIocs]);

  console.log("rendering Own IOCs")

  const title = "CCCE / My IOCs";
  useGlobalAppBar(title);

  const closeModal = () => {
    setIOCFormOpen(false);
  }  

  function preFilter(iocs) {
    console.log(iocs);
    const abcIOCs = iocs.filter((ioc) => ioc.owner === user.loginName).sort((a, b) => a.latestVersion.namingName.localeCompare(b.latestVersion.namingName));
    return abcIOCs;
  }

  let content = (
      <>
      <Hidden smUp>
          <SearchableIOCList iocs={preFilter(iocs)} setQuery={setQuery}/>
      </Hidden>
      <Hidden xsDown>
          <SearchableIOCTable iocs={preFilter(iocs)} setQuery={setQuery}/>
      </Hidden>
      </>
  );

  return (
    <Container>
      <Paper>
        <Grid container spacing={1} justify="flex-end">
          <Grid item xs={10}>
            <Box display="flex" flexDirection="row" p={2} m={1}>
            <Typography variant="h2">
              My IOCs
            </Typography>
            </Box>
          </Grid>
          <Grid item xs={2}>
            <Box display="flex" flexDirection="row-reverse" p={2} m={1}>
              <Button variant="contained" color="secondary" onClick={() => { setIOCFormOpen(true) }}>New IOC</Button>
            </Box>
          </Grid>
          <Grid item xs={12}>
            {content}
          </Grid>
          <SimpleModal open={iocFormOpen} setOpen={setIOCFormOpen}>
            <CreateIOC open={iocFormOpen} setOpen={setIOCFormOpen} isUpdateIoc={false} submitCallback={closeModal} hook={useCreateIOC} title="Create new IOC" buttonText="Create"/>
          </SimpleModal>
        </Grid>
      </Paper>
    </Container>
  );
}

