import React, { useState, useEffect } from 'react';
import {
    Paper,
    Link,
    Container,
    Hidden,
    IconButton,
    Card, 
    CardContent,
    Typography, 
    Divider
} from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import ArrowBackIcon from '@material-ui/icons/ArrowBack';
import { useHost, useHostIOCList, } from '../../api/SwaggerApi';
import { useGlobalAppBar } from '../../components/navigation/GlobalAppBar/GlobalAppBar';
import { HostBadge } from '../../components/host/HostBadge';
import { SimpleAccordion } from '../../components/common/Accordion/SimpleAccordion';
import { SearchableIOCList } from '../../components/IOC/IOCList';
import { SearchableIOCTable } from '../../components/IOC/IOCTable';
import { KeyValueTable } from '../../components/common/KeyValueTable/KeyValueTable';
import { LokiPanel } from '../../components/common/Loki/LokiPanel';
import { useHistory } from "react-router-dom";
import { formatDate } from '../../components/common/Helper';

const useStyles = makeStyles((theme) => ({
  root: {
    marginBottom: theme.spacing(2),
  },
  cardContent: {
    margin: theme.spacing(2),
  },
  divider: {
    marginTop: theme.spacing(2),
    marginBottom: theme.spacing(2),
  },
}));

export function HostDetailsView({ match }) {
    const id = parseInt(match.params.id);
    useGlobalAppBar("CCCE / Host Details");
    const [host] = useHost(id);
    const [iocs] = useHostIOCList(id);
    const [query, setQuery] = useState();
    const [deployedIocs, setDeployedIocs] = useState();
    const history = useHistory();
    const classes = useStyles();
    console.log({ ...iocs });
    console.log({ ...host });

    useEffect(() => setDeployedIocs((iocs?.deployed ?? []).filter(ioc => ioc.namingName.toLowerCase().includes(query) ||
        (ioc.host && ioc.host.toLowerCase().includes(query)) ||
        ioc.git.toLowerCase().includes(query) ||
        ioc.version.toLowerCase().includes(query) ||
        ioc.owner.toLowerCase().includes(query) ||
        (ioc.status && ioc.status.toLowerCase().includes(query)))), [query, iocs]);

    const renderHost = { ...host?.csEntryHost };
    delete renderHost.id;
    renderHost.interfaces = <pre>{JSON.stringify(host?.csEntryHost?.interfaces, null, 2)}</pre>;
    renderHost.ansible_vars = <pre>{JSON.stringify(host?.csEntryHost?.ansible_vars, null, 2)}</pre>
    renderHost.ansible_groups = <pre>{JSON.stringify(host?.csEntryHost?.ansible_groups, null, 2)}</pre>
    const createdAt = renderHost.created_at;
    delete renderHost.created_at;
    renderHost["created at"] = formatDate(createdAt);

    const handleClick = (event) => {
        history.goBack();
    };

    return (
        <Container>
            <Paper className={classes.root}>
                <IconButton color="inherit" onClick={handleClick}>
                    <ArrowBackIcon />
                </IconButton>
                {host && <HostBadge host={host} />}
                <SimpleAccordion summary="Deployed IOCs" defaultExpanded>
                    <Hidden smUp>
                        <SearchableIOCList iocs={deployedIocs} setQuery={setQuery}/>
                    </Hidden>
                    <Hidden xsDown>
                        <SearchableIOCTable iocs={deployedIocs} setQuery={setQuery} forHostDetails="true"/>
                    </Hidden>
                </SimpleAccordion>
                <SimpleAccordion summary="Syslog info" defaultExpanded>
                    {host && <LokiPanel host={host} isSyslog={true} isDeployed={true} />}
                </SimpleAccordion>  
                <Card variant="outlined">
                    <CardContent className={classes.cardContent}>
                        <Typography variant="h6">
                        Open in CSEntry
                        </Typography>
                        <Link href={`https://csentry.esss.lu.se/network/hosts/view/${host?.csEntryHost.name}`} target="_blank" rel="noreferrer">{`https://csentry.esss.lu.se/network/hosts/view/${host?.csEntryHost?.name}`}</Link>
                        <Divider className={classes.divider}/>
                        <Typography>
                            <Link href={`https://grafana.tn.esss.lu.se/d/5zJT23xWz/node-exporter-full?orgId=1&var-node=${host?.csEntryHost.fqdn}`} target="_blank" rel="noreferrer">Open Grafana Dashboard</Link>
                        </Typography>
                    </CardContent>
                </Card>
                <SimpleAccordion summary="CSEntry Configuration">

                    {host && <KeyValueTable obj={renderHost} variant="table" />}
                </SimpleAccordion>
            </Paper>
        </Container>
    );
}