import React, { useEffect } from "react";
import { Container, Paper } from "@material-ui/core";
import { KeyValueTable } from '../../components/common/KeyValueTable/KeyValueTable';
import { useStatistics } from "../../api/SwaggerApi";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";

const clone = (obj) => Object.assign({}, obj);

const renameKey = (object, key, newKey) => {

    const clonedObj = clone(object);
    const targetKey = clonedObj[key];

    delete clonedObj[key];
    clonedObj[newKey] = targetKey;

    return clonedObj;
};

export function StatisticsView() {

    const title = "CCCE / Statistics";
    useGlobalAppBar(title);

    const [statistics, getStatistics] = useStatistics();

    useEffect(() =>
        getStatistics()
        , [getStatistics]
    );

    let renderStat = { ...statistics };

    //rename "response fields" into readable format
    if (statistics) {
        renderStat = renameKey(renderStat, "numberOfActiveIocs", " Number of active IOCs (Prometheus)");
        renderStat = renameKey(renderStat, "numberOfActiveHosts", " Number of active Hosts (Prometheus)");
        renderStat = renameKey(renderStat, "numberOfCreatedIocs", " Number of IOCs created (DB)");
        renderStat = renameKey(renderStat, "numberOfActiveDeployments", " Number of active deployments (DB)");
        renderStat = renameKey(renderStat, "numberOfDeployments", " Total number of deployments (DB)");
    }

    return (
        <Container>
            <h2>Statistics</h2>
            <Paper>

                {statistics && <KeyValueTable obj={renderStat} variant="table" />}
            </Paper>
        </Container>
    )

}