import React from 'react';
import { Tooltip } from "@material-ui/core";
import RedGitIcon from "../../icons/resources/git/Red Git Pull.png";
import YellowGitIcon from "../../icons/resources/git/Yellow Git Pull.png";


/**
 * Creates secondary icon that represents the GIT state. GIT state comes from GIT exporters from Prometheus.
 * If repo is not dirty, and has no local commits no icon will show!
 * 
 * IconSet donloaded from: https://chrispennington.blog/blog/20201123-git-icon-set/
 * 
 * @param {*} isDirty represents if the repo state is dirty
 * @param {*} hasLocalCommits represents if repo has local commits
 * 
 * @returns Icons tiwh tooltip.
 */
export default function IOCGitExporter({isDirty, hasLocalCommits, shrink}) {
  
  if ((isDirty === true) || (hasLocalCommits === true)) {
    return(
      <Tooltip title="IOC has been modified">
        <img src={RedGitIcon} alt="Git error" style={{ width: shrink, height: shrink}}/>
      </Tooltip>
    );
  }
  
  if ((isDirty === null) || (hasLocalCommits === null)) {
    return(
    <Tooltip title="Git repository state: unknown">
        <img src={YellowGitIcon} alt="Git error" style={{ width: shrink, height: shrink}}/>
      </Tooltip>
    );
  }

  return <></>;
}